@@ -41,7 +41,7 @@ struct _GstFFMpegVidEnc
   AVCodecContext *context;
   AVFrame *picture;
   GstClockTime pts_offset;
-  gboolean opened;
+  gint64 last_pts_ff;
   gboolean need_reopen;
   gboolean discont;
   guint pass;
